/*
 * tkresolver - Telekinesis testing software
 *
 * Copyright (C) 2004, 2005, 2006, 2007, 2008 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <boost/assign/list_of.hpp>

#include "intent_selector.h"

using namespace Tk;
using namespace Experimenter;



IntentSelector:: IntentSelector(Db::Database * database,
				unsigned trace_count,
				const String &algorithm_spec,
				bool test)
  : _store( Gtk::ListStore::create(_columns) )
{
  set_model(_store);
  append_column("Code", _columns.code);
  append_column("Description", _columns.description);
  
  fill_list(database, trace_count, algorithm_spec, test);
}

void
IntentSelector:: fill_list(Db::Database * database,
			   unsigned trace_count,
			   const String &algorithm_spec,
			   bool test)
{
  Db::IntentInfoList info( database->get_intent_options(trace_count) );
  String default_intent( database->choose_intent(trace_count, algorithm_spec, test) );
  
  for (Db::IntentInfoList::iterator iter( info.begin() );
       iter != info.end();
       ++iter)
    {
      Gtk::ListStore::iterator row( _store->append() );
      
      row->set_value(_columns.code, wstring_to_ustring(Tk::String(iter->first)));
      row->set_value(_columns.description, wstring_to_ustring(Tk::String(iter->second)));
      
      // default
      if (iter->first == default_intent)
	get_selection()->select(row);
    }
}

Db::Code
IntentSelector:: get_intent_code()
{
  return get_selection()->get_selected()->get_value(_columns.code);
}
