/* -*- c++ -*-
 * tkresolver - Telekinesis testing software
 *
 * Copyright (C) 2008 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "libtkdbui/value.h"
#include "libtkdbui/boolean_value.h"
#include "libtkdbui/numeric_value.h"
#include "libtkdbui/string_value.h"
#include "libtkdbui/temporal_value.h"
#include "libtkdbui/file_value.h"
#include "libtkdb/database.h"

using namespace Tk::Db::Ui;

Value:: Value(Tk::Db::Data::Type type)
  : _type(type)
{
}

void
Value:: emit()
{
  _signal_value_changed.emit(Tk::Db::Data::Value(_type));
}

void
Value:: emit(const Tk::Db::Data::datum &datum)
{
  _signal_value_changed.emit(Tk::Db::Data::Value(_type, datum));
}

Value::SignalValueChanged
Value:: signal_value_changed()
{
  return _signal_value_changed;
}

Value *
Value:: create(const Tk::Db::Data::Value &source)
{
  using namespace Tk::Db::Data;
  switch(source.get_type())
    {
    case Boolean: return new BooleanValue(source.get_value<bool>());
    case Integer: return new NumericValue(source.get_value<long>());
    case Double: return new NumericValue(source.get_value<double>());
    case Tk::Db::Data::String: return new StringValue(source.get_value<Tk::String>());
    case Timestamp: return new TemporalValue(source.get_value<Tk::Db::DateTime>());
    case Tk::Db::Data::Date: return new TemporalValue(source.get_value<Tk::Db::Date>());
    case Blob: return new FileValue(source.get_value<Tk::Db::Bytes>());
    default: throw Tk::Db::UnknownType(static_cast<int>(source.get_type()), "Db::Ui::Value Value parameter");
    }
}

Value *
Value:: create(const Tk::Db::Data::Type &type)
{
  using namespace Tk::Db::Data;
  switch(type)
    {
    case Boolean:
      return new BooleanValue();
    case Integer:
    case Double:
      return new NumericValue(type);
    case Tk::Db::Data::String:
      return new StringValue();
    case Timestamp:
    case Tk::Db::Data::Date:
      return new TemporalValue(type);
    case Blob:
      return new FileValue();
    default: throw Tk::Db::UnknownType(static_cast<int>(type), "Db::Ui::Value parameter");
    }
}

Tk::Db::Data::Type
Value:: get_type() const
{
  return _type;
}
