/* -*- c++ -*-
 * tkresolver - Telekinesis testing software
 *
 * Copyright (C) 2008 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef __TK_DB_UI_VALUE_H__
#define __TK_DB_UI_VALUE_H__

#include <gtkmm.h>

#include "libtkdb/value.h"

namespace Tk {
  namespace Db {
    namespace Ui {
      
      template <typename E>
      void throw_bad_type(const Tk::Db::Data::Type &type)
      {
	throw E(std::string("Bad value type `")
		+ static_cast<std::string>(Tk::String(static_cast<int>(type)))
		+ "'");
      }
      
      class Value
      {
      private:
	Tk::Db::Data::Type _type;
	
      public:
	typedef sigc::signal<void, const Tk::Db::Data::Value &> SignalValueChanged;
	SignalValueChanged signal_value_changed();
	
      protected:
	SignalValueChanged _signal_value_changed;
	
	Value(Tk::Db::Data::Type type);
	
	void emit();
	void emit(const Tk::Db::Data::datum &datum);
	Tk::Db::Data::Type get_type() const;
	
	template <typename E>
	void bad_type() const
	{ Tk::Db::Ui::throw_bad_type<E>(_type); };
	
      public:
	virtual ~Value() {}
	static Value *create(const Tk::Db::Data::Type &type);
	static Value *create(const Tk::Db::Data::Value &source);
      };
      
    } /* namespace Ui */
  } /* namespace Db */
}; /* namespace Tk */

#endif /* __TK_DB_UI_VALUE_H__ */
