/* -*- c++ -*-
 * tkresolver - Telekinesis testing software
 *
 * Copyright (C) 2008 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#include "libtkquery/parse_error.h"

using namespace Tk::Query;

ParseError:: ParseError(const Location &loc, const std::string &type, const std::string &msg)
  : std::runtime_error(type
		       + " error at line "
		       + static_cast<std::string>(Tk::String(loc.begin.line))
		       + ", column "
		       + static_cast<std::string>(Tk::String(loc.begin.column))
		       + ": "
		       + msg),
    _location(loc),
    _message(msg)
{
}

const Location &
ParseError:: get_location() const
{
  return _location;
}

const std::string &
ParseError:: get_message() const
{
  return _message;
}


SyntaxError:: SyntaxError(const Location &loc, const std::string &msg)
  : ParseError(loc, get_type(), msg)
{
}

std::string
SyntaxError:: get_type() const
{
  return "Syntax";
}

SemanticError:: SemanticError(const Location &loc, const std::string &msg)
  : ParseError(loc, get_type(), msg)
{
}

std::string
SemanticError:: get_type() const
{
  return "Semantic";
}
